@@ -1,11 +1,9 @@
 import inspect
 import os
 import sys
-import warnings
-warnings.simplefilter("always")
 
-__version__ = (0,1,3)
-version = '.'.join(map(str,__version__))
+__version__ = 1.0
+version = __version__
 
 try:
     unicode
@@ -43,19 +41,15 @@ def use(conf_source):
     '''
 
     if isinstance(conf_source, basestring):
-        conf_dict = from_file(conf_source)
+        conf_dict = conf_from_file(conf_source)
     elif inspect.ismodule(conf_source):
-        conf_dict = from_module(conf_source)
+        conf_dict = conf_from_module(conf_source)
 
     _locals_dict = sys._getframe(1).f_locals
     _locals_dict.update(conf_dict)
 
 
 def conf_from_module(module):
-    warnings.warn("Deprecated. Use configit.from_module", DeprecationWarning)
-    return from_module(module)
-
-def from_module(module):
     '''
     Creates a configuration dictionary from a module.
 
@@ -65,16 +59,12 @@ def from_module(module):
     if isinstance(module, str):
         module = import_module(module)
     module_dict = dict(inspect.getmembers(module))
-    conf_dict = from_dict(module_dict)
+    conf_dict = conf_from_dict(module_dict)
 
     return conf_dict
 
 
 def conf_from_file(filepath):
-    warnings.warn("Deprecated. Use configit.from_file", DeprecationWarning)
-    return from_file(filepath)
-
-def from_file(filepath):
     '''
     Creates a configuration dictionary from a file.
 
@@ -85,25 +75,20 @@ def from_file(filepath):
     conf_dict = {}
 
     try:
-        with open(abspath , 'rb') as f:
-            content = f.read()
-        exec(compile(content, abspath, 'exec'), globals(), conf_dict)
+        exec(compile(open(abspath).read(), abspath, 'exec'),
+             globals(), conf_dict)
     except IOError as ioerror:
         raise IOError('Error while trying to get configuration from file: '
                       '%s\n'
                       '%s' % (abspath, ioerror))
 
-    conf_dict = from_dict(conf_dict)
+    conf_dict = conf_from_dict(conf_dict)
     conf_dict['__config_file__'] = abspath
 
     return conf_dict
 
 
 def conf_from_dict(conf_dict):
-    warnings.warn("Deprecated. Use configit.from_file", DeprecationWarning)
-    return from_dict(conf_dict)
-
-def from_dict(conf_dict):
     '''
     Creates a configuration dictionary from a dictionary.
 
@@ -118,12 +103,23 @@ def from_dict(conf_dict):
         if inspect.ismodule(v):
             continue
         if isinstance(v, dict):
-            v = from_dict(v)
+            v = conf_from_dict(v)
 
         conf[k] = v
     return conf
 
 
+def convert_str_to_config(conf_path):
+    conf_path = conf_path.replace(r'/', '.')
+
+    fromlist = conf_path.split('.')
+    if fromlist[-1] == 'py':
+        fromlist = fromlist[:-1]
+    name = '.'.join(fromlist)
+
+    return name, fromlist
+
+
 def import_module(conf):
     '''
     Imports the configuration as a module.
